@@ -65,4 +65,4 @@ def main(config: DictConfig) -> None:
 
 
 if __name__ == "__main__":
-    pass
+    main()
